@@ -34,8 +34,7 @@ struct _EvAnnotation {
 	gchar           *contents;
 	gchar           *name;
 	gchar           *modified;
-	GdkColor         color;
-
+	GdkRGBA          rgba;
 };
 
 struct _EvAnnotationClass {
@@ -78,7 +77,8 @@ enum {
 	PROP_ANNOT_CONTENTS,
 	PROP_ANNOT_NAME,
 	PROP_ANNOT_MODIFIED,
-	PROP_ANNOT_COLOR
+	PROP_ANNOT_COLOR,
+        PROP_ANNOT_RGBA
 };
 
 /* EvAnnotationMarkup */
@@ -174,6 +174,9 @@ ev_annotation_set_property (GObject      *object,
 	case PROP_ANNOT_COLOR:
 		ev_annotation_set_color (annot, g_value_get_pointer (value));
 		break;
+        case PROP_ANNOT_RGBA:
+                ev_annotation_set_rgba (annot, g_value_get_boxed (value));
+                break;
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
 	}
@@ -197,9 +200,16 @@ ev_annotation_get_property (GObject    *object,
 	case PROP_ANNOT_MODIFIED:
 		g_value_set_string (value, ev_annotation_get_modified (annot));
 		break;
-	case PROP_ANNOT_COLOR:
-		g_value_set_pointer (value, &annot->color);
+	case PROP_ANNOT_COLOR: {
+                GdkColor color;
+
+                ev_annotation_get_color (annot, &color);
+		g_value_set_pointer (value, &color);
 		break;
+        }
+        case PROP_ANNOT_RGBA:
+                g_value_set_boxed (value, &annot->rgba);
+                break;
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
 	}
@@ -220,34 +230,60 @@ ev_annotation_class_init (EvAnnotationClass *klass)
 							      "Page",
 							      "The page wehere the annotation is",
 							      EV_TYPE_PAGE,
-							      G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
+							      G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY |
+                                                              G_PARAM_STATIC_STRINGS));
 	g_object_class_install_property (g_object_class,
 					 PROP_ANNOT_CONTENTS,
 					 g_param_spec_string ("contents",
 							      "Contents",
 							      "The annotation contents",
 							      NULL,
-							      G_PARAM_READWRITE));
+							      G_PARAM_READWRITE |
+                                                              G_PARAM_STATIC_STRINGS));
 	g_object_class_install_property (g_object_class,
 					 PROP_ANNOT_NAME,
 					 g_param_spec_string ("name",
 							      "Name",
 							      "The annotation unique name",
 							      NULL,
-							      G_PARAM_READWRITE));
+							      G_PARAM_READWRITE |
+                                                              G_PARAM_STATIC_STRINGS));
 	g_object_class_install_property (g_object_class,
 					 PROP_ANNOT_MODIFIED,
 					 g_param_spec_string ("modified",
 							      "Modified",
 							      "Last modified date as string",
 							      NULL,
-							      G_PARAM_READWRITE));
+							      G_PARAM_READWRITE |
+                                                              G_PARAM_STATIC_STRINGS));
+        /**
+         * EvAnnotation:color:
+         *
+         * The colour of the annotation as a #GdkColor.
+         *
+         * Deprecated: 3.6: Use #EvAnnotation:rgba instead.
+         */
 	g_object_class_install_property (g_object_class,
 					 PROP_ANNOT_COLOR,
 					 g_param_spec_pointer ("color",
 							       "Color",
 							       "The annotation color",
-							       G_PARAM_READWRITE));
+							       G_PARAM_READWRITE |
+                                                               G_PARAM_STATIC_STRINGS));
+
+        /**
+         * EvAnnotation:rgba:
+         *
+         * The colour of the annotation as a #GdkRGBA.
+         *
+         * Since: 3.6
+         */
+        g_object_class_install_property (g_object_class,
+                                         PROP_ANNOT_COLOR,
+                                         g_param_spec_boxed ("rgba", NULL, NULL,
+                                                             GDK_TYPE_RGBA,
+                                                             G_PARAM_READWRITE |
+                                                             G_PARAM_STATIC_STRINGS));
 }
 
 EvAnnotationType
@@ -489,18 +525,27 @@ ev_annotation_set_modified_from_time (EvAnnotation *annot,
 /**
  * ev_annotation_get_color:
  * @annot: an #EvAnnotation
- * @color (out): a #GdkColor to be filled with the Annotation color.
+ * @color: (out): a #GdkColor to be filled with the Annotation color.
  *
  * Get the color of @annot.
+ *
+ * Deprecated: 3.6: Use ev_annotation_get_rgba() instead.
  */
 void
 ev_annotation_get_color (EvAnnotation *annot,
 			 GdkColor     *color)
 {
-	g_return_if_fail (EV_IS_ANNOTATION (annot));
+        GdkRGBA rgba;
 
-	if (color)
-		*color = annot->color;
+	g_return_if_fail (EV_IS_ANNOTATION (annot));
+        g_return_if_fail (color != NULL);
+
+        ev_annotation_get_rgba (annot, &rgba);
+
+        color->pixel = 0;
+        color->red = CLAMP (rgba.red * 65535. + 0.5, 0, 65535);
+        color->green = CLAMP (rgba.green * 65535. + 0.5, 0, 65535);
+        color->blue = CLAMP (rgba.blue * 65535. + 0.5, 0, 65535);
 }
 
 /**
@@ -513,26 +558,79 @@ ev_annotation_get_color (EvAnnotation *annot,
  * notify::color signal on @annot.
  *
  * Returns: %TRUE  when the color has been changed, %FALSE otherwise.
+ *
+ * Deprecated: 3.6: Use ev_annotation_set_rgba() instead.
  */
 gboolean
 ev_annotation_set_color (EvAnnotation   *annot,
 			 const GdkColor *color)
 {
+        GdkColor annot_color;
+        GdkRGBA rgba;
+
 	g_return_val_if_fail (EV_IS_ANNOTATION (annot), FALSE);
 
-	if (annot->color.red == color->red &&
-	    annot->color.green == color->green &&
-	    annot->color.blue == color->blue)
-		return FALSE;
+        ev_annotation_get_color (annot, &annot_color);
+        if (color == NULL || gdk_color_equal (color, &annot_color))
+                return FALSE;
 
-	if (color)
-		annot->color = *color;
+        rgba.red = color->red / 65535.;
+        rgba.green = color->green / 65535.;
+        rgba.blue = color->blue / 65535.;
+        rgba.alpha = 1.;
 
+        ev_annotation_set_rgba (annot, &rgba);
 	g_object_notify (G_OBJECT (annot), "color");
 
 	return TRUE;
 }
 
+/**
+ * ev_annotation_get_rgba:
+ * @annot: an #EvAnnotation
+ * @rgba: (out): a #GdkRGBA to be filled with the annotation color
+ *
+ * Gets the color of @annot.
+ *
+ * Since: 3.6
+ */
+void
+ev_annotation_get_rgba (EvAnnotation *annot,
+                        GdkRGBA      *rgba)
+{
+        g_return_if_fail (EV_IS_ANNOTATION (annot));
+        g_return_if_fail (rgba != NULL);
+
+        *rgba = annot->rgba;
+}
+
+/**
+ * ev_annotation_set_rgba:
+ * @annot: an #Evannotation
+ * @rgba: a #GdkRGBA
+ *
+ * Set the color of the annotation to @rgba.
+ *
+ * Returns: %TRUE if the color has been changed, %FALSE otherwise
+ *
+ * Since: 3.6
+ */
+gboolean
+ev_annotation_set_rgba (EvAnnotation  *annot,
+                        const GdkRGBA *rgba)
+{
+        g_return_val_if_fail (EV_IS_ANNOTATION (annot), FALSE);
+        g_return_val_if_fail (rgba != NULL, FALSE);
+
+        if (gdk_rgba_equal (rgba, &annot->rgba))
+                return FALSE;
+
+        annot->rgba = *rgba;
+        g_object_notify (G_OBJECT (annot), "rgba");
+
+        return TRUE;
+}
+
 /* EvAnnotationMarkup */
 typedef struct {
 	gchar   *label;
@@ -553,7 +651,8 @@ ev_annotation_markup_default_init (EvAnnotationMarkupInterface *iface)
 									  "Label",
 									  "Label of the markup annotation",
 									  NULL,
-									  G_PARAM_READWRITE));
+									  G_PARAM_READWRITE |
+                                                                          G_PARAM_STATIC_STRINGS));
 		g_object_interface_install_property (iface,
 						     g_param_spec_double ("opacity",
 									  "Opacity",
@@ -561,28 +660,32 @@ ev_annotation_markup_default_init (EvAnnotationMarkupInterface *iface)
 									  0,
 									  G_MAXDOUBLE,
 									  1.,
-									  G_PARAM_READWRITE));
+									  G_PARAM_READWRITE |
+                                                                          G_PARAM_STATIC_STRINGS));
 		g_object_interface_install_property (iface,
-						     g_param_spec_boolean ("has_popup",
+						     g_param_spec_boolean ("has-popup",
 									   "Has popup",
 									   "Whether the markup annotation has "
 									   "a popup window associated",
 									   TRUE,
-									   G_PARAM_READWRITE));
+									   G_PARAM_READWRITE |
+                                                                           G_PARAM_STATIC_STRINGS));
 		g_object_interface_install_property (iface,
 						     g_param_spec_boxed ("rectangle",
 									 "Rectangle",
 									 "The Rectangle of the popup associated "
 									 "to the markup annotation",
 									 EV_TYPE_RECTANGLE,
-									 G_PARAM_READWRITE));
+									 G_PARAM_READWRITE |
+                                                                         G_PARAM_STATIC_STRINGS));
 		g_object_interface_install_property (iface,
-						     g_param_spec_boolean ("popup_is_open",
+						     g_param_spec_boolean ("popup-is-open",
 									   "PopupIsOpen",
 									   "Whether the popup associated to "
 									   "the markup annotation is open",
 									   FALSE,
-									   G_PARAM_READWRITE));
+									   G_PARAM_READWRITE |
+                                                                           G_PARAM_STATIC_STRINGS));
 		initialized = TRUE;
 	}
 }
@@ -682,9 +785,9 @@ ev_annotation_markup_class_install_properties (GObjectClass *klass)
 
 	g_object_class_override_property (klass, PROP_MARKUP_LABEL, "label");
 	g_object_class_override_property (klass, PROP_MARKUP_OPACITY, "opacity");
-	g_object_class_override_property (klass, PROP_MARKUP_HAS_POPUP, "has_popup");
+	g_object_class_override_property (klass, PROP_MARKUP_HAS_POPUP, "has-popup");
 	g_object_class_override_property (klass, PROP_MARKUP_RECTANGLE, "rectangle");
-	g_object_class_override_property (klass, PROP_MARKUP_POPUP_IS_OPEN, "popup_is_open");
+	g_object_class_override_property (klass, PROP_MARKUP_POPUP_IS_OPEN, "popup-is-open");
 }
 
 const gchar *
@@ -920,14 +1023,16 @@ ev_annotation_text_class_init (EvAnnotationTextClass *klass)
 							    "The icon fo the text annotation",
 							    EV_TYPE_ANNOTATION_TEXT_ICON,
 							    EV_ANNOTATION_TEXT_ICON_NOTE,
-							    G_PARAM_READWRITE));
+							    G_PARAM_READWRITE |
+                                                            G_PARAM_STATIC_STRINGS));
 	g_object_class_install_property (g_object_class,
 					 PROP_TEXT_IS_OPEN,
-					 g_param_spec_boolean ("is_open",
+					 g_param_spec_boolean ("is-open",
 							       "IsOpen",
 							       "Whether text annot is initially open",
 							       FALSE,
-							       G_PARAM_READWRITE));
+							       G_PARAM_READWRITE |
+                                                               G_PARAM_STATIC_STRINGS));
 }
 
 static void
@@ -1073,7 +1178,8 @@ ev_annotation_attachment_class_init (EvAnnotationAttachmentClass *klass)
 							      "The attachment of the annotation",
 							      EV_TYPE_ATTACHMENT,
 							      G_PARAM_CONSTRUCT |
-							      G_PARAM_READWRITE));
+							      G_PARAM_READWRITE |
+                                                              G_PARAM_STATIC_STRINGS));
 }
 
 static void
